#
# spec file for package gramps
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2010 Dominique Leuenberger, Amsterdam, Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global __requires_exclude typelib\\(GtkosxApplication\\)|typelib\\(Gtkspell\\)

Name:           gramps
Version:        4.2.0
Release:        5.15
Summary:        Genealogical Research Software
License:        GPL-2.0+
Group:          Productivity/Other
Url:            http://www.gramps-project.org/
Source:         http://downloads.sourceforge.net/project/gramps/Stable/4.2.0/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE gramps-no-translations-check.patch boo#941490 dimstar@opensuse.org -- Do not warn on missing translations
Patch0:         gramps-no-translations-check.patch
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  python3
# Needed for typelib() - Requires.
BuildRequires:  gobject-introspection
BuildRequires:  hicolor-icon-theme
# We need the %%mime_database_* macros
BuildRequires:  shared-mime-info
BuildRequires:  update-desktop-files
Requires:       python3-bsddb3
Requires:       python3-cairo
Requires:       python3-gobject >= 3.12.0
Requires:       xdg-utils
Recommends:     %{name}-lang
Recommends:     graphviz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Gramps gives you the ability to record the many details of an
individual's life as well as the complex relationships between
various people, places and events. All of your research is kept
organized, searchable and as precise as you need it to be.

%lang_package
%prep
%setup -q
%patch0 -p1

%build
python3 setup.py build

%install
python3 setup.py install --root="%{buildroot}"
# fix resource-path containing buildroot information
echo -n %{_datadir} > %{buildroot}%{python3_sitelib}/gramps/gen/utils/resource-path
# Application Registry is obsolete since GNOME 2.8.
rm -r %{buildroot}%{_datadir}/mime-info
# Icon is installed in a non-default location
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/48x48/apps
mv %{buildroot}%{_datadir}/icons/gramps.png %{buildroot}%{_datadir}/icons/hicolor/48x48/apps
# We package those files as package docs...
rm -r %{buildroot}%{_datadir}/doc/%{name}/
%suse_update_desktop_file -r %{name} Office Database
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}

%post
%desktop_database_post
%icon_theme_cache_post
%icon_theme_cache_post gnome
%mime_database_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%icon_theme_cache_postun gnome
%mime_database_postun

%files
%defattr (-,root,root)
%doc AUTHORS COPYING FAQ LICENSE NEWS README
%{_bindir}/%{name}
%{_datadir}/%{name}/
%dir %{_datadir}/appdata
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/gnome/
%{_datadir}/mime/packages/%{name}.xml
%{python3_sitelib}/%{name}/
%{python3_sitelib}/%{name}-%{version}-*.egg-info
%{_mandir}/man1/%{name}.1%{?ext_man}
# We can't really move the localized manpages to the lang package, since they'd
# create a conflict between the lang subpackage and bundles
%lang(cs) %{_mandir}/cs/man1/%{name}.*
%lang(fr) %{_mandir}/fr/man1/%{name}.*
%lang(nl) %{_mandir}/nl/man1/%{name}.*
%lang(pl) %{_mandir}/pl/man1/%{name}.*
%lang(sv) %{_mandir}/sv/man1/%{name}.*
%lang(pt_BR) %{_mandir}/pt_BR/man1/%{name}.*
# man doesn't provide those directories, so we have to own them
%lang(cs) %dir %{_mandir}/cs
%lang(cs) %dir %{_mandir}/cs/man1
%lang(nl) %dir %{_mandir}/nl
%lang(nl) %dir %{_mandir}/nl/man1
%lang(pl) %dir %{_mandir}/pl
%lang(pl) %dir %{_mandir}/pl/man1
%lang(sv) %dir %{_mandir}/sv
%lang(sv) %dir %{_mandir}/sv/man1
%lang(pt_BR) %dir %{_mandir}/pt_BR
%lang(pt_BR) %dir %{_mandir}/pt_BR/man1

%files lang -f %{name}.lang

%changelog
* Wed Aug 12 2015 dimstar@opensuse.org
- Add gramps-no-translations-check.patch: Disable gramps internal
  test if localization files are available. As gramps is properly
  packaged, we know where the translations are and don't want to
  alert a user with annoying popups (boo#941490).
* Mon Aug  3 2015 dimstar@opensuse.org
- Update to version 4.2.0:
  + New date and language fields on place name.
  + Review on GtkBuilder, fix some Gtk3 warnings and move from
    deprecated methods.
  + Change icons and buttons handling methods.
  + Enhanced Place Editor and new Place Name editor.
  + New widget: use own interactive-search.
  + Ability to import kml data into Geography views.
  + Enhancement for removing multiple selected items from Views
    (action group).
  + Add drag support on more Views, Selectors and Editors.
  + Add right-click "Copy all" to ListModel and all QuickTables.
  + Review Alternate Place handling and edition.
  + New 'Place' configuration keys set by user (settings).
  + New filter rule: is enclosed by.
  + Consistency on Privacy option for reports.
  + Consistency on "Name-format" options for reports.
  + Add DeferredFilter class (a subclass of GenericFilter).
  + New textual Report: Links on Notes.
  + Fix alphabetic index and toc bug in books.
  + Enhancements on Style Editor.
  + Enhancements on End Notes into textual reports.
  + Changes on Individuals complete textual report.
  + Changes on Ancestors Tree draw report: Include Siblings.
  + Add name-format option, and deferred translation on Records
    report.
  + Add deferred translation on Timeline draw report.
  + Enable attributes gramplet on Source and Citation Views.
  + New place locations gramplet.
  + Optimizations around index, Flat and TreeView models.
  + Enhanced samples files.
  + All importers return now an ImportInfo object.
  + Experimental gwplus (geneweb) import file format support.
  + Remove experimental HTML renderer view.
  + New test scripts.
  + New Date handler for Japanese.
  + Review on Slovenian and Czech Date Handlers.
  + Updated translations.
- Drop gramps-webkit3.0.patch: no longer applicable.
- Add python3 BuildRequires: follow upstreams port to python3.
- Drop python-webkitgtk, python-gtkspell and python-PyICU
  recommends: no longer valid after the port to python3.
- Add python3-bsddb3, python3-cairo  and python3-gobject
  Requires: new dependencies.
* Sat May  2 2015 zaitor@opensuse.org
- Update to version 4.1.3:
  + Fix db upgrade failure
  + GtkDialog mapped without a transient parent
  + [Gedcom]:
  - SUBN and SUBM record handling
  - Import/export round trip causes lost information
  - Entering a witness to an event such as marriage might be
    ignored
  - Gramps can't import estim. date period exported by itself
  - 1/4 and 1/2 ANSEL characters not supported on importing
    ANSEL
  - Importing file containing multibyte UTF-8 characters fails
  - Import fails for ANSI file under python 3
  - Failure importing ANSEL encoded gedcom file
  - Characters ignored on a Gedcom encoded ANSI (cp1252 West
    Europe, USA)
  - NameError in importer
  - Event address is lost on import, i.e. disconnected from
    event
  + Crash on geneweb export with python3
  + GuiColorOption missing avail-changed event handler
  + Bad generation of [timeline report] ODT files since 4.0.0
  + Fix bad handle in explanation note for unknown event
  + Fix spurious generation of empty 'Alternative Name' in
    place.merge()
  + Support creating directories in various scenarios
  + Attempting to add a bookmark causes an error
  + Long series of "unhandled exception" popup boxes while doing a
    check & repair
  + Crash when trying to link existing place as an enclosing place
    using P0001 number
  + HTML view fails to load
  + Relationship Graph crashes
  + Python3 needs new_subpixbuf not subpixbuf
  + Regression: running gramps from crontab fails
  + tag_map is not initialized
  + Some labels now fit better on citations sidebar filter
  + Event columns in web narrative are too narrow
  + Problem by start program (launcher)
  + Translation string missing in Not Related tool for help and
    close button
  + Date format month/year is not well reported at editing time [in
    Italian]
  + Fix unknown gender relationships handler for the french locale
  + Fix a handle type bug on sidebar filter
  + Tidy up About dialog
  + Cleanup on some man files
  + Convert some remaining unicode literals
  + Fix mac menubar setting
  + Enable python3 to run po/update_po.py
  + Updated translations.
* Mon Mar  9 2015 dimstar@opensuse.org
- Update to version 4.1.2:
  + Error converting python2 utf-8 strings to python3 str when
    loading data from database.
  + Removing a parent place from a place leaves a dangling
    reference.
  + Error during checking the database.
  + Stubborn blank space in database won’t be removed, fix removing
    rows in flat list views.
  + Database upgrade fails if default media path is not set.
  + Error converting database after upgrade to Gramps 4.1.1.
  + Error in a single place within the places section.
  + Entries from the add-or-choose selector of
    Place/Source/Media/Note cannot be dragged.
  + Enclosing places tab should work like other similar tabs, new
    place reference editor.
  + Association editor refuses dropped persons.
  + Error on opening twice an object from clipboard.
  + Incorrect spacing in export assistant file chooser.
  + New Event types are saved as a disordered list.
  + Always display main participants.
  + Place titles can now be generated on-the-fly by a place
    displayer, default is still to use the place title field.
  + GEDCOM import of embedded notes attached to media does not
    work.
  + Crash on Ancestry.com .ged import; consistent.
  + Errors handling owner/submitter information in GEDCOM files.
    Only import researcher from GEDCOM or XML if the family tree
    was originally empty.
  + GEDCOM export does not export media attached to citations.
  + The fanchart view crashes if max generation is set to 1 away.
  + Sidebar Filters do not match placetypes in new placeview, two
    new filter rules (HasTitle, HasData).
  + Fix bug when family has no parents.
  + Fix bad handle in explanation note for unknown event.
  + Some labels now fit better on citations sidebar filter.
  + Views in Geography should not always use the last option set by
    the user.
  + Request for keyboard-controlled zoom on Geography view.
  + Error geography view – Displaying main menu.
  + Configure screen needs a file selector to select directory for
    “offline mode” files.
  + Filter panel on geography view displays improperly.
  + Detailed descendant report crashes, bibliography (citations).
  + Can’t disable box shadow in SVG descendant tree.
  + Descendant tree graphical report, syntax error in svg output.
  + Regression: Complete Individual report has
    partially-untranslated output.
  + Events Page in Narrative Report not working.
  + Gramps freeze after defining a report style with German cm
    values.
  + Various problems with docgen.TextDoc.add_media_object.
  + Report event attribute name is not translated.
  + Records Gramplet uses wrong text.
  + Closing detached gramplet causes python to crash.
  + Cannot reduce size of gramplets detached from a gramplet bar.
  + Gramplets don’t fill window when detached from dashboard.
  + ImageMetadata doesn’t show metadata.
  + typo on GLib call, used by an addon only.
  + Fix error setting gramplet tab label.
  + Check for active person in session log gramplet.
  + Spurious spaces in CLI List Family Trees, tab delimited output.
  + Print statements changed to assemble the whole line before
    output.
  + Gtk3 warning and custom undoableentry widget, (bgo#644927).
  + Warnings: deprecated Gtk properties and errors loading theme
    icon.
  + Fix: database manager dialog is inconsistent for older gtk+3
    versions.
  + Warnings: deprecated Gtk properties and errors loading theme
    icon.
  + Fix: Error loading theme icon ‘gtk-apply’.
  + gramps fails to start with gtk+-3.13.3.
  + Places in data.gramps are not in the new Place hierarchy.
  + Upgrade the version of some dependencies for Mac OS and
    Windows OS.
  + Keywords entry in gramps.desktop does not work.
  + ‘Available Gramps Updates for Addons’ window not on top.
  + Some text not translatable in context menu fancharts.
  + Fix for Unit test.
  + Updated translations.
- Drop gramps-4.1.1-Glib-typo.patch: fixed upstream.
- Move .desktop file to Office;Database category: it certainly is
  a stretch, but Education;Science is no longer valid and
  Science;Humanities is not officially registered.
* Wed Feb  4 2015 schubert.seb@gmail.com
- Add gramps-4.1.1-Glib-typo.patch: fix typo, which removes wrong
  automatic dependency; already applied upstream for 4.1.2.
- Remove comment about osm-gps-map because it is already detected.
* Thu Jan 15 2015 p.drouand@gmail.com
- Update to version 4.1.1
  + Fix custom place types in the place editor.
  + Allow place type combobox to receive focus.
  + Store custom place types in the metadata table.
  + Fix place type for places without a main location.
  + Fix bug adding parent places to a new place.
  + Prevent user creating a cycle in the place hierarchy.
  + Avoid infinite loop when place cycle encountered.
  + Prevent creation of a place cycle when merging.
  + Fix error when no place is selected.
  + Check that a place has been selected when saving.
  + Use the standard place selection widget to be consistent..
  + Add a new Top Level place through the Place Reference Editor.
  + Fix backlinks code in place report.
  + Backlinks for places can now also be places as well as events.
  + Fix check and repair tool for empty placerefs.
  + Update location utilities to work with proxies.
  + Place report does not run.
  + Update place details gramplet.
  + Locations are now displayed in a new separate gramplet.
  + Add check for empty handle in gramplets.
  + Check DB lock on the recent opened trees list.
  + Sidebarfilter gramplet does not fit well into People, Events or
    Media views.
  + Fix new event default type considering existing events with
  * default + role.
  + Rebuild secondary indexes after database upgrade.
  + Importing gedcom files containing multibyte UTF-8 characters
    fails.
  + Ahnentafel Report did not use Christening Date if no Birth
    Date.
  + [Narweb:] Missing webpage for media under some circumstances.
  + Fix narrated web report with gendex option enabled.
  + Tweak to "default" CSS choice for the narrated web report.
  + Invalid link for Merge citation Help button.
  + Fix 'todo' gramplet.
  + Fix path when using drag & drop to add media.
  + Limit the number of generations displayed in the ancestor
    gramplet.
  + Export of a subset of the tree failed.
  + Fix issues in python3, and bytes-string mismatch with ICU.
  + Fix url/uri handling with non-ascii characters under linux and
    mac.
  + Fix name format on graphical reports.
  + Fix name format on textual reports.
  + Better GUI support for embeded custom attributes list on media
    object.
  + Better keys for search under linux shells (.desktop file).
  + 'Unknown' person in detailed ancestor report can not be
    translated.
  + Translations don't show in many labels.
  + Ensure python text domain gets the right encoding.
  + Translate some punctuation marks.
  + Various fixes around Geography and osmgpsmap.
  + Allow gramplets to be displayed in the dashboard only.
  + Update FSF address.
  + Add Arabic-script, Islamic-date, Thai script, Married Name and
    more dates examples.
  + Fix on czech date handler for calculated and estimated dates.
  + Enhance Serbian date handler to handle Cyrillic dates.
  + Simplify Canadian Ash Wednesday holiday.
  + Re-enable Esperanto support (for non-Windows OS only) after a
    large review.
  + Updated translations.
- Remove python-gtk-devel Requires: no longer needed after the
  project moved to python-gobject.
- Add hicolor-icon-theme BuildRequires: do not own standard
  hicolor directories.
* Mon Jul 28 2014 dimstar@opensuse.org
- Add gramps-webkit3.0.patch: specify in the code that we require
  WebKit 3.0, not 'any' WebKit (bnc#887048).
- No longer filter typelib(OsmGpsMap) from automatic dependency
  scanner: we now have osm-gps-map 1.0.1 available.
* Tue Jul 22 2014 dimstar@opensuse.org
- Drop gnome-icon-theme (Build)Requires: no longer functional after
  the merging of the themes into Adwaita theme, which in turn is a
  dependency to GTK+ 3.0.
* Sun Jun  8 2014 rbrown@opensuse.org
- Fix source URL in spec
* Thu May 29 2014 ecsos@schirra.net
- Update to version 4.0.4:
  + Upgrade to db version 17 fails in Python 3 due to use
    of iteritems
  + Database corrupted – TypeError: unhashable type: ‘list’
  + Fix bug in abandon changes and quit
  + Paths, unicode and bsddb module
  + Consistency on create_id method
  + Better handling for non-ASCII characters on database-path
  + Better support for ANSEL characters
  + ‘Display as’ field in Name Editor reverts to
    Preferences default
  + Fix vcard date converter
  + View does not communicate over proxy server with autorisation
  + Enhanced Bookmark support
  + Event gramplet filter does not have field for primary role
  + New HasDayOfWeek filter rule
  + Error when leaving a Gramps type field blank in an editor
  + Fix creation of events with same Gramps-ID
  + Crash when opening details of a person
  + Fix spacing on dialogs for some recent linux distributions
  + date editor and Date class allow e.g. Hebrew dates
    with newyear (Mar25)
  + Fix crash in fan chart view when scrolling
  + Poor contrast mouse on mouse over
  + Drag and drop only one data into Editors tabs
  + Unable to edit citations on association
  + Enhancements and consitency on events gramplet, selector
    and view
  + Sometimes says ‘no data exists for note’ when saving
  + Enhanced Citation Editor
  + Do not always raise errors when some plugins are hidden
  + Remove hover selection from embedded lists
  + Fix update of active object after merge
  + Cleanup on warnings and messages around locale directory
  + Media Editor error if Path value was changed to a non existing
    file
  + Register history objects at startup
  + Avoid dumb encoding error when compiling gpr file
  + Work around Py2Cairo
  + Given Name Cloud Gramplet splits up given names into words
  + Users should not be allowed to edit and delete ‘default’ style
    into Style Editor
  + Filename Decoding Error in Graphical Reports
  + Missing closing bracket in Web_Basic-Spruce.css
  + Reorder tool: global name ‘gen’ is not defined
  + Some fixes and enhancements
  + Fix start in East Asian language, force UTF-8 locale on Mac
  + Fix apple_collation on Mac
  + Spelling messages at random cause hang for a few seconds.
  + Media viewer list crashes during start if one try to select
    an entry where the media isn’t available
  + ‘Available Gramps Updates for Addons’ window not on top
  + HTML View fails to load
  + Paper names and Styles values are now translated
  + Sort failure using glocale.sort_key
  + Improve support for collation variants
  + Translate some punctuation marks
  + Fix unit tests and python3 issues
  + Fix Relationships handler for Portuguese
  + Updated translations: ar, cs, de, fi, fr, he, it, lt, nb, nl,
    pl, pt_BR, ru, sv, uk
* Tue Jan 28 2014 zaitor@opensuse.org
- Update to version 4.0.3:
  + Fix copy via context menu on Views into Charts Category.
  + Fix Tab sequence in Name Editor.
  + Fix citations gramplet into media view.
  + Fix unhandled exception when inspecting media.
  + Fix Citation sidebar filter for python3.
  + Fix add link to a "Html code" note.
  + Fix message on backup dialog.
  + Fix space for selection lists.
  + Fix spell with myspell and LANG.
  + Fix changes root cursor to hand.
  + Recent file parser now gives the file location.
  + Fix vertical overflows on check and repair-tool dialog.
  + Fix custom key/value (data item) on Database difference report.
  + Fix unhandled exception in media exif information under Windows
    OS.
  + Fix person selector in searchfilter under Windows OS.
  + Starting Gramps without console is now possible under Windows
    OS.
  + Specific OS handling.
  + Common fixes and changes with 3.4.7.
  + Updated translations.
* Tue Nov 26 2013 zaitor@opensuse.org
- Update to version 4.0.2:
  + Citation merge works better for all objects with citations.
  + Fixed citations attached to family events.
  + Fixed several crashes, hangs, and data corruption scenarios.
  + Fixed bugs in determining whether a person is alive,
    potentially resolving private data leak via export or report.
  + Fixed bugs on proxies.
  + VCF export/import now support gender information.
  + Several bugs with filtering fixed, most filters now support
    regular expressions.
  + Fixed bug in Hebrew calendar date calculations.
  + Fix some regressions on GEDCOM file format export and
    enhancement on CONT/CONC handling.
  + Multiple fixes and improvements on gramplets.
  + Multiple fixes in the narrated website and web calendar
    reports.
  + Enhancements on date and calendar.
  + Some fixes and improvements of the webapp.
  + Fix on Database Differences module.
  + Enhancements of the citation tree view (Sources category).
  + Improvements on User classes.
  + Polish and consistency on Gramps XML export.
  + Bump XML schema to 1.5.1.
  + Fixed several long-standing problems with report generation.
  + Better support of RTL locales (Arabic, Hebrew, etc.) in GUI.
  + Better support for selected lang on some reports.
  + Better way for displaying missing dependencies.
  + Better Spell support.
  + Platform-specific fixes for Mac and Windows.
  + Add printing functionality for all geography views.
  + New date handlers for Arabic and Greek.
  + Repaired and enhanced tests broken since 3.3.x, resulting in
    overall reliability improvements.
  + Add a support for AppData.
  + Updated translations.
- Drop gramps-4_0-gtk-3_8.patch, fixed upstream.
* Sun Jun 30 2013 dimstar@opensuse.org
- Add gramps-4_0-gtk-3_8.patch: Fix execution with GTK+ 3.8.
* Sat Jun 29 2013 zaitor@opensuse.org
- Update to version 4.0.1:
  + Gtk3: fix menu on person editor and Geography views, convert
    deprecated code for the indicator in entryfield.
  + Gedcom: Fix crash on export when there are addresses, fix space
    on ID.
  + Disallow bookmarking a source in the Citation Tree View.
  + Better RTL support on Pedigreeview and position for gramplets.
  + Fix bad scaling in address editor.
  + Fix crash on ancestor chart report.
  + Fix navigation issues with selected line.
  + Fix size of the 'Tip of the day' dialog.
  + Fix right-click on tables in Quick Views.
  + Fix cursor corruption on Pedigree view.
  + Improvements when exporting via CLI.
  + Reports: Various fixes on dialogs, output file formats and
    cleanup on error messages.
  + MacOS: Fix bad filename on Gramps URL, osm-gps-map revision,
    image paths, resource-path file, maclocale.
  + Move the HTML resources from gramps/plugins/webstuff to Data
    and Images.
  + Alternate Names in Person Details Gramplet.
  + New holidays, date and relationship handlers for Ukrainian.
  + Enhancements for testing localized Relationship handlers.
  + More names and events on data.gramps sample.
  + Updated translations.
* Sat Jun 22 2013 dimstar@opensuse.org
- Add gobjet-introspection BuildRequires: needed in order for the
  code to be inspected and typelib() Requires be added to the
  package.
- Filter out the following typelib() Requires:
  + typelib(GtkosxApplication)is not needed on Linux.
  + typelib(OsmGpsMap) is optional and currently not available in
    openSUSE.
  + typelib(Gtkspell) is an obsolete name which gramps can cope
    with as an alternative to GtkSpell (different spelling).
* Thu May 23 2013 dimstar@opensuse.org
- Update to version 4.0.0:
  + Conversion to GTK 3 and use of gobject introspection, GEPS#029.
  + Support for python 3, GEPS#031.
  + Code reorganization, GEPS#008.
  + Autotools is no longer used for building Gramps, distutils is
    used, GEPS#026.
  + Completely reworked localization handling.
  + The Gramplet view has been renamed Dashboard. This to avoid an
    overload of the word Gramplet, and to make it more clear to new
    users what can be expected in this view
  + GTK 3 uses new themes, so users not on Gnome must set a nice
    GTK 3 theme to fully appreciate Gramps 4.0. Install a GTK 3
    theme and set it. If Gramps looks ugly, you made an error in
    this step.
  + Different sidebar navigators can be installed
  + New Ancestor Fan Chart View and Descendant Fan Chart View,
    which offer a lot of insight in your family tree on a small
    space. Direct printing is available from these views.
  + All wizards are reworked, so the exporter dialog, help and bug
    report dialog are different from version 3.4, but offer the
    same functions.
  + New To Do Gramplets listing all To Do Notes.
  + More reports support output in a different language than the
    interface language
  + Narrative Web has been reworked to make it more stable.
- Rewrite build and install sections to adapt to the switch to
  pythonm distutils, away from autotools.
- Add python-PyICU recommends: it's not strictly required to
  operate, but strongly recommended.
* Wed May 15 2013 dimstar@opensuse.org
- Update to version 3.4.4:
  + Infinite recursion bug in narrative web generation.
  + Protection on family trees when using version 3.4 and 4.0 on
    the same PC (road to 4.0).
  + Merging notes of media with citations now works.
  + Crash during Calculate Preview of a filtered XML export.
  + Fix annoying errors on navigation related to citations gramplet
    and tag object.
  + Listing the Family Trees can corrupt them.
  + Various fix around handling Gedcom file format.
  + Fix citations and sources import on ProGen format.
  + Better date handling and better alternate translation support.
    on some textual reports according to locale under windows.
  + Avoid Errors when setting wrong value as markup for invalid
    dates (Preferences).
  + Fix paragraph layout on PDF format or print output.
  + New: New-Zealand holidays.
  + Polish and backport code on XML import (road to 4.0).
  + Regular expression rules now use search rather than match, fix
    design issues on regex filter rules.
  + Disable/Enable indent spouse on descendants tree.
  + Fix regular expressions on Place filter rule.
  + Consistency on cli arguments (road to 4.0).
  + Fix call of non-existant process on references proxy, enhanced
    tests on proxy filter.
  + Fix NarWeb creation via cli for some non-english locales.
  + Updated translations.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 3.4.3:
  + Sorting (both in the main display window, and particularly in
    Narrative Web output) now uses PyICU.
  + The automatic Addon checking and download now works once again.
  + Import from Pro-Gen has been updated.
  + Import and Export of address fields in GEDCOM has been
    improved.
  + GEDCOM Repositories not imported correctly from FTM.
  + Fixes to a number of errors in filtering notes.
  + Fix some errors in determining whether someone is alive.
  + Make availability of GraphViz settings depend on output format.
  + Improve the descriptions and tooltip for GraphViz aspect ratio
    option.
  + Fixed update problems with citation bottombar gramplet.
  + Fixed Open Document Text output in Book report.
  + A number of changes to Narrative Web.
  + Updated translations.
* Wed Oct 31 2012 dimstar@opensuse.org
- Update to version 3.4.2:
  + Some fixes on NarrativeWeb report.
  + Some fixes on book report.
  + Improvement on database path interface and user's preferences.
  + Consistency on Name display and regex support.
  + Some platform-specific fixes for Windows system environment.
  + Better support for media links on Gedcom file format.
  + Fix possible incorrect family relations on Gedcom file format.
  + Various fixes on citation records.
  + Fix and improve places handling on Geography views.
  + Fix on command line arguments.
  + Consistency on PDF file format.
  + Updated translations.
* Sun Sep 16 2012 zaitor@opensuse.org
- Update to version 3.4.1:
  + Fixed error in export to xml of family order.
  + Fixed crash in windows after some use due to too much terminal
    output.
  + Some platform-specific fixes (Windows, OSX).
  + Misc bug fixes.
  + Updated translations.
* Wed May 23 2012 zaitor@opensuse.org
- Update to version 3.4.0:
  + Lots of changes and bug fixes to every part of Gramps,
    including XML import/export, image handling, gedom handling,
    Gramplets, date handling, citations, reports, more!
  + Some platform-specific fixes (Windows, OSX, Linux).
  + Updated translations.
- Remove _version define as it stays equal to %%version.
* Sat May 19 2012 zaitor@opensuse.org
- Update to version 3.3.2:
  + Expressive error when trying to load familytree with
    downgraded Berkeley db.
  + Fix in the image offset calculation (MediaRef Editor).
  + Improved focus and bug fixes on Editors.
  + Enhancements on ODT file format.
  + Improved synchronization on gramplets.
  + Export, filtering and database log improvements.
  + Call of living proxy is more accurate when using NarrativeWeb
    report.
  + Fixes on Check and Repair, Sort Events and Clipboard tools.
  + Fix automate version.
  + Fixes on PedigreeView (database state and mouse events).
  + Various fixes and improvements on merge code.
  + Minor fixes on report interface and output.
  + Various fixes on Narrative and Web Calendar reports.
  + Minor issues on Gedcom handling.
  + Add Japanese holidays (reports).
  + Add a Relationship calculator for Catalan.
  + More than 50 bug fixes and improvements.
  + Updated translations.
* Mon Oct  3 2011 vuntz@opensuse.org
- Add explicit shared-mime-info BuildRequires since we use the
  %%mime_database_* macros.
* Sun Oct  2 2011 zaitor@opensuse.org
- Update to version 3.3.1:
  + Various bugs fixed.
  + Updated translations.
* Wed Jun 15 2011 vuntz@opensuse.org
- Update to version 3.3.0:
  + New "person name" dialog and workflow with better (or new!)
    support for nickname, complicated multiple surnames, patronymic
    as surname, family nickname, and name format preferences
  + Gramplet bottombar and sidebar per view, with new gramplets
    such as details view and image metadata viewer/editor
  + Ability to tag objects; this is the next version of what used
    to be called "markers" in previous versions of Gramps
  + Geography view now uses osm-gps-map
  + New locality field in the place editor; hierarchy is now:
    Country, State, County, City, Locality, Street
  + Automatic check and upgrade of plugins on startup
  + Improved merge support of objects
  + Better descendant/ancestor tree reports
  + Undo/redo on entry fields (CTRL+Z, CTRL+SHIFT+Z)
  + Backup option in the exporter
  + Exporter based on filters with preview
  + Various under-the-hood improvements, including for performance.
  + Updated translations.
- Add python-gtkspell Recommends as we do have the package.
- Update FIXME about missing Recommends: python-enchant is not used
  anymore, but python-exiv2 and osm-gps-map are new optional
  dependencies.
- Stop using source service to download the tarball, as Factory
  will move away from this.
* Mon May  2 2011 dimstar@opensuse.org
- Update to version 3.2.6:
  + fix memory leaks
  + fix corrupted reports
  + fix crash in cramplets
  + fix gedcom import and export
  + import speed improvements
  + NarrativeWeb fixes
  + prevent corrupting databases
  + Updated translations.
- Use set_version source service.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
* Tue Dec  7 2010 vuntz@opensuse.org
- Update to version 3.2.5:
  + Fix Gramps so it again runs with Python 2.5
  + Write all notes and sources to gedcom files
  + Cli fixes
  + GeneWeb and LegacyGedcom fixes
  + NarrativeWeb fixes
  + Memory leak fixes
  + Various other small fixes
  + Updated translations
- Add gnome-icon-theme BuildRequires for directory ownership.
- Add gnome-icon-theme, python-gtk, xdg-utils Requires, as
  documented by upstream.
- Add graphviz, python-webkitgtk Recommends, as documented by
  upstream.
- Improve description.
- Also remove the deprecated mime data files from
  /usr/share/mime-info, not just /usr/share/application-registry
- Call %%mime_database_post and %%mime_database_postun macros in
  %%post/%%postun since we install a xml mime file.
- Tag localized man pages with the right language. We should
  eventually move them to the lang subpackage, but at the moment,
  they would create a file conflict between bundles and the lang
  subpackage.
* Thu Nov  4 2010 dimstar@opensuse.org
- Initial package, version 3.2.4
